@@ -6,18 +6,18 @@
     <message>
         <location filename="../src/mainwindow.ui" line="14"/>
         <source>OpenSSH Authentication Passphrase request</source>
-        <translation>Pedido de senha de autenticação OpenSSH</translation>
+        <translation>Pedido de palavra-passe de autenticação OpenSSH</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="20"/>
         <source>Enter your SSH passphrase for request:</source>
-        <translation>Escreva a sua senha SSH para o pedido:</translation>
+        <translation>Digite a palavra-passe SSH para o pedido:</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/main.cpp" line="39"/>
+        <location filename="../src/main.cpp" line="52"/>
         <source>unknown request</source>
         <translation>pedido desconhecido</translation>
     </message>
